@@ -256,6 +256,8 @@ impl MyApp {
             let mib = fl!("mib");
 
             for pu in &self.buf_data.stat.fdinfo.proc_usage {
+                if pu.ids_count == 0 { continue; }
+
                 ui.label(pu.name.to_string());
                 ui.label(format!("{:>8}", pu.pid));
                 ui.label(if pu.is_kfd_process { " Y " } else { "" });
@@ -305,6 +307,8 @@ impl MyApp {
             let mib = fl!("mib");
 
             for pu in &self.buf_data.stat.xdna_fdinfo.proc_usage {
+                if pu.ids_count == 0 { continue; }
+
                 ui.label(pu.name.to_string());
                 ui.label(format!("{:>8}", pu.pid));
                 ui.label(format!("{:5} {mib}", pu.usage.total_memory >> 10));
@@ -448,13 +452,13 @@ impl MyApp {
             let min_max = if let [Some(min), Some(max)] = [sensors.min_dpm_link, sensors.max_dpm_link] {
                 format!(
                     " (Gen{}x{} - Gen{}x{})",
-                    min.gen,
+                    min.r#gen,
                     min.width,
-                    max.gen,
+                    max.r#gen,
                     max.width,
                 )
             } else if let Some(max) = sensors.max_dpm_link {
-                format!(" ({} Gen{}x{})", fl!("max"), max.gen, max.width)
+                format!(" ({} Gen{}x{})", fl!("max"), max.r#gen, max.width)
             } else {
                 String::new()
             };
@@ -462,7 +466,7 @@ impl MyApp {
             ui.label(format!(
                 "{} => Gen{}x{} {min_max}",
                 fl!("pcie_link_speed"),
-                cur.gen,
+                cur.r#gen,
                 cur.width,
             ));
         }
@@ -506,8 +510,10 @@ impl MyApp {
                 ui.label(format!("{label} Temp. ({val:4} C)"));
                 ui.end_row();
 
-                let points: PlotPoints = temp_history.iter()
-                    .map(|(i, val)| [i, val as f64]).collect();
+                let points: PlotPoints = temp_history
+                    .iter()
+                    .map(|(i, val)| [i, val as f64])
+                    .collect();
                 let line = Line::new(points).fill(0.0);
 
                 default_plot(label)
@@ -522,6 +528,32 @@ impl MyApp {
             n += 1;
             if n % 2 == 1 { ui.end_row(); }
         }
+
+        if let Some(ref tctl) = sensors.tctl {
+            let label = "CPU Tctl";
+            egui::Grid::new(label).show(ui, |ui| {
+                ui.label(format!("CPU Tctl ({:3} C)", tctl / 1000));
+                ui.end_row();
+
+                let points: PlotPoints = self.buf_data.history.sensors_history.tctl
+                    .iter()
+                    .map(|(i, val)| [i, val as f64])
+                    .collect();
+                let line = Line::new(points).fill(0.0);
+
+                default_plot(label)
+                    .include_y(0)
+                    .include_y(100)
+                    .label_formatter(label_fmt)
+                    .auto_bounds([true, true].into())
+                    .height(SENSORS_HEIGHT)
+                    .width(SENSORS_WIDTH)
+                    .show(ui, |plot_ui| plot_ui.line(line));
+            });
+
+            n += 1;
+            if n % 2 == 1 { ui.end_row(); }
+        }
     }
 
     pub fn egui_pcie_bw(&self, ui: &mut egui::Ui) {
